QueueRouteReportsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueRouteReportsInput({required int startReportId, required int endReportId, Map<String, dynamic>? $unknown})
const
factory
QueueRouteReportsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $QueueRouteReportsInputCopyWith<QueueRouteReportsInput>
Create a copy of QueueRouteReportsInput with the given fields replaced by the non-null parameter values.
no setterinherited
endReportId int
End of report ID range (inclusive). Difference between start and end must be less than 5,000.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startReportId int
Start of report ID range (inclusive).
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueRouteReportsInput value)) → TResult

Available on QueueRouteReportsInput, provided by the QueueRouteReportsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueRouteReportsInput value)?) → TResult?

Available on QueueRouteReportsInput, provided by the QueueRouteReportsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueRouteReportsInput value)?, {required TResult orElse()}) → TResult

Available on QueueRouteReportsInput, provided by the QueueRouteReportsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int startReportId, int endReportId, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueRouteReportsInput, provided by the QueueRouteReportsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueRouteReportsInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int startReportId, int endReportId, Map<String, dynamic>? $unknown)) → TResult

Available on QueueRouteReportsInput, provided by the QueueRouteReportsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int startReportId, int endReportId, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueRouteReportsInput, provided by the QueueRouteReportsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>