ReportGetLiveStatsInput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $ReportGetLiveStatsInputCopyWith<
ReportGetLiveStatsInput> -
Create a copy of ReportGetLiveStatsInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasModeratorDid → bool
-
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputExtension extension
no setter - hasNotModeratorDid → bool
-
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputExtension extension
no setter - hasNotQueueId → bool
-
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputExtension extension
no setter - hasQueueId → bool
-
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputExtension extension
no setter - moderatorDid → String?
-
Filter stats by moderator DID.
no setterinherited
- queueId → int?
-
Filter stats by queue. Use -1 for unqueued reports.
no setterinherited
-
reportTypes
→ List<
String> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ReportGetLiveStatsInput value)) → TResult -
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ReportGetLiveStatsInput value)?) → TResult? -
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ReportGetLiveStatsInput value)?, {required TResult orElse()}) → TResult -
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int? queueId, String? moderatorDid, List< String> ? reportTypes, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ReportGetLiveStatsInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int? queueId, String? moderatorDid, List< String> ? reportTypes, Map<String, dynamic> ? $unknown)) → TResult -
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int? queueId, String? moderatorDid, List< String> ? reportTypes, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on ReportGetLiveStatsInput, provided by the ReportGetLiveStatsInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>